Documentation
¶
Overview ¶
Package password configures argon2 to be compatible with Perl Convos.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrInvalidHash = errors.New("the encoded hash is not in the correct format") ErrIncompatibleVersion = errors.New("incompatible version of argon2") ErrUnsupportedFormat = errors.New("unsupported hash format") ErrUnsupportedVariant = errors.New("unsupported argon2 variant") ErrTooLongToken = errors.New("the encoded hash is too long to be processed") )
Functions ¶
func ComparePassword ¶
ComparePassword compares a password with a hash (Argon2 or Bcrypt).
func GenerateHash ¶
GenerateHash generates a hash for a password. It defaults to Argon2id for new hashes.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.